@@ -1,7 +1,8 @@
 #! /bin/sh
 
 ##  Command line parameters:
-##     ./run_regression_test.sh [-simple] [test1] [test2] ...
+##     ./run_regression_test.sh [-simple] [-nosuccess] [test1] [test2] ...
+##  If "-nosuccess" is specified, then the passing tests are omitted
 ##  If "-simple" is specified, only the status of the test is returned, not
 ##  the actual diff
 
@@ -9,6 +10,7 @@
 tmp_ext="`whoami`_$$"
 test_output='output'
 ref_output='test.out'
+diff_output=diff_$$
 build_script='build'
 test_script='test.cmd'
 verbose='no'
@@ -18,10 +20,10 @@ pipe_error() {
   echo "!!!! Interrupted !!!!"
   exit -1
 }
-trap pipe_error PIPE INT QUIT TERM
+trap pipe_error PIPE INT QUIT TERM > /dev/null 2>&1
 
 ## Add read_ali to the path
-PATH=`pwd`/../standalone_obj/:$PATH
+PATH=`pwd`/../standalone_obj/:`pwd`../sn/snsrc/snavigator/db:$PATH
 export PATH
 
 ### Some global files...
@@ -41,6 +43,12 @@ if [ "$1" = "-simple" ]; then
    simple=1
 fi
 
+nosuccess=0
+if [ "$1" = "-nosuccess" ]; then
+   shift
+   nosuccess=1
+fi
+
 tests="$@"
 if [ "$tests " = " " ]; then
    tests=*
@@ -74,61 +82,64 @@ do
    if [ -f .gnatdebug ]; then
       unset ADA_DEBUG_FILE
    else
-      export ADA_DEBUG_FILE=$GNATDEBUG
+      ADA_DEBUG_FILE=$GNATDEBUG
+      export ADA_DEBUG_FILE
    fi
 
    current_dir=`basename $current_dir`
-   if [ $current_dir != "parse_all" -a -d $current_dir -a $current_dir != '.' -a $current_dir != 'CVS' ]
+   if [ -d $current_dir -a $current_dir != '.' -a $current_dir != 'CVS' ]
    then
-      copy_dir=${current_dir}_${tmp_ext}
+      if [ -f $current_dir/DO_NOT_RUN ]; then
+         echo "+++++++++  $current_dir (NOT RUN)"
+      else
+         copy_dir=${current_dir}_${tmp_ext}
 
-      if [ -f $current_dir/$test_script ]; then
-         cp -R $current_dir $copy_dir
-         cd $copy_dir
-         rm -rf .gpssnprj/
+         if [ -f $current_dir/$test_script ]; then
+            cp -pr $current_dir $copy_dir
+            cd $copy_dir
+            find . -name .gpssnprj -exec rm -rf {} \; 2>/dev/null
 
-         if [ -f $build_script ]; then
-             echo "" >> $build_output
-             echo "--  Building in $current_dir:" >> $build_output
-             sh ./$build_script >> $build_output 2>&1
-         fi
-
-         if echo $expected_failure | fgrep " $current_dir " >/dev/null; then
-            is_expected="(expected)"
-         else
-            is_expected=""
-         fi
-
-         test_parse $test_script > $test_output 2>&1 
-         if [ -f $ref_output ]; then
-            if [ $simple = 0 ]; then
-               echo "---------  $current_dir $is_expected"
-               diff -c $ref_output $test_output
+            if [ -f $build_script ]; then
+                echo "" >> $build_output
+                echo "--  Building in $current_dir:" >> $build_output
+                sh ./$build_script >> $build_output 2>&1
+            fi
+   
+            if echo $expected_failure | fgrep " $current_dir " >/dev/null; then
+               is_expected="(not ideal)"
             else
-               diff $ref_output $test_output >/dev/null 2>&1
-               if [ $? -ne 0 ]; then
-                  echo "+++++++++  $current_dir (FAILURE) $is_expected"
-               else
+               is_expected=""
+            fi
+
+            diff_params="-c"
+            if [ $current_dir = "parse_all" ]; then
+               diff_params=""
+            fi
+   
+            test_parse $test_script | tr -d '\r' > $test_output 2>&1 
+
+            if [ -f $ref_output ]; then
+               diff $diff_params $ref_output $test_output > $diff_output
+            else
+               cat $test_output > $diff_output
+            fi
+
+            if [ -s $diff_output ]; then
+               echo "+++++++++  $current_dir (FAILURE) $is_expected"
+               if [ $simple = 0 ]; then
+                  cat $diff_output
+               fi
+            else
+               if [ $nosuccess = 0 ]; then
                   echo "---------  $current_dir $is_expected"
                fi
             fi
-         else
-            if [ $simple = 0 ]; then
-               echo "---------  $current_dir $is_expected"
-               cat $test_output
-            elif [ -z $test_output ]; then
-               echo "---------  $current_dir $is_expected"
-               true
-            else
-               echo "+++++++++  $current_dir (FAILURE) $is_expected"
-            fi
-         fi
-       
-         cd .. 
 
-         rm -rf $copy_dir
-      else
-         echo "$current_dir: test.cmd missing, test skipped." > $build_output
+            cd .. 
+            rm -rf $copy_dir
+         else
+            echo "$current_dir: $test_script missing, test skipped." > $build_output
+         fi
       fi
    fi
 done
@@ -138,4 +149,8 @@ if [ "$verbose" = "yes" ]; then
    cat $build_output
 fi
 
+if [ $nosuccess = 1 ]; then
+   echo "Done"
+fi
+
 rm $build_output
